@@ -4,7 +4,7 @@
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
-	the Free Software Foundation; either version 2 of the License, or
+	the Free Software Foundation; either version 3 of the License, or
 	(at your option) any later version.
 
 	This program is distributed in the hope that it will be useful,
@@ -30,7 +30,7 @@ struct ctcp_handle;
  * CTCP command handling
  */
 struct ctcp_handler {
-	const char *name;
+	char *name;
 	void (*fn) (struct ctcp_handle *, char **args);
 };
 
@@ -38,8 +38,8 @@ gboolean ctcp_process_network_request(struct network *, struct line *);
 gboolean ctcp_process_network_reply(struct network *, struct line *);
 gboolean ctcp_process_client_request(struct client *, struct line *);
 gboolean ctcp_process_client_reply(struct client *, struct line *);
-void ctcp_register_handler(const struct ctcp_handler *);
-void ctcp_send(struct network *, const char *, ...);
-void ctcp_reply(struct ctcp_handle *, ...);
+G_MODULE_EXPORT void ctcp_register_handler(const struct ctcp_handler *);
+G_MODULE_EXPORT G_GNUC_NULL_TERMINATED void ctcp_send(struct network *, const char *, ...);
+G_MODULE_EXPORT G_GNUC_NULL_TERMINATED void ctcp_reply(struct ctcp_handle *, ...);
 
 #endif /* __CTCP_H__ */
