@@ -1,10 +1,10 @@
 /* 
 	ctrlproxy: A modular IRC proxy
-	(c) 2002-2006 Jelmer Vernooij <jelmer@nl.linux.org>
+	(c) 2002-2007 Jelmer Vernooij <jelmer@nl.linux.org>
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
-	the Free Software Foundation; either version 2 of the License, or
+	the Free Software Foundation; either version 3 of the License, or
 	(at your option) any later version.
 
 	This program is distributed in the hope that it will be useful,
@@ -158,6 +158,25 @@ static gboolean marshall_char(struct network_state *nst, const char *name, int l
 	}
 }
 
+static gboolean marshall_long(struct network_state *nst, const char *name, int level, enum marshall_mode m, GIOChannel *t, long *n)
+{
+	if (m == MARSHALL_PUSH) {
+		char tmp[10];
+		g_snprintf(tmp, sizeof(tmp), "%ld", *n);
+		return marshall_set(t, level, name, tmp);
+	} else {
+		char *tmp;
+		gboolean ret = marshall_get(t, level, name, &tmp);
+		if (!ret) return FALSE;
+
+		*n = atol(tmp);
+
+		g_free(tmp);
+
+		return TRUE;
+	}
+}
+
 static gboolean marshall_int(struct network_state *nst, const char *name, int level, enum marshall_mode m, GIOChannel *t, int *n)
 {
 	if (m == MARSHALL_PUSH) {
@@ -226,6 +245,7 @@ static gboolean marshall_network_nick (struct network_state *nst, const char *na
 	ret &= marshall_string(nst, "username", level+1, m, t, &n->username);
 	ret &= marshall_string(nst, "hostname", level+1, m, t, &n->hostname);
 	ret &= marshall_string(nst, "hostmask", level+1, m, t, &n->hostmask);
+	ret &= marshall_string(nst, "server", level+1, m, t, &n->server);
 	if (m == MARSHALL_PULL)
 		n->channel_nicks = NULL;
 	return ret;
@@ -314,12 +334,13 @@ static gboolean marshall_channel_state (struct network_state *nst,
 	ret &= marshall_string(nst, "name", level+1, m, t, &(*c)->name);
 	ret &= marshall_string(nst, "key", level+1, m, t, &(*c)->key);
 	ret &= marshall_string(nst, "topic", level+1, m, t, &(*c)->topic);
+	ret &= marshall_string(nst, "topic_set_by", level+1, m, t, &(*c)->topic_set_by);
+	ret &= marshall_long(nst, "topic_set_time", level+1, m, t, &(*c)->topic_set_time);
 	ret &= marshall_GList(nst, "banlist", level+1, m, t, &(*c)->banlist, (marshall_fn_t)marshall_banlist_entry);
 	ret &= marshall_GList(nst, "invitelist", level+1, m, t, &(*c)->invitelist, (marshall_fn_t)marshall_string);
 	ret &= marshall_GList(nst, "exceptlist", level+1, m, t, &(*c)->exceptlist, (marshall_fn_t)marshall_string);
 	(*c)->network = nst;
 
-
 	marshall_struct(t, m, level+1, "nicks");
 
 	/* Nicks  */
@@ -393,6 +414,9 @@ static gboolean marshall_network_state(enum marshall_mode m, GIOChannel *t,
 
 #define STATE_DUMP_INTERVAL 1000
 
+/**
+ * Linestack_file backend data
+ */
 struct lf_data {
 	GIOChannel *line_file;
 	GIOChannel *state_file;
