@@ -4,7 +4,7 @@
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
-	the Free Software Foundation; either version 2 of the License, or
+	the Free Software Foundation; either version 3 of the License, or
 	(at your option) any later version.
 
 	This program is distributed in the hope that it will be useful,
@@ -29,9 +29,9 @@
  * Nickname/password combination for a particular network or globally.
  */
 struct nickserv_entry {
-	const char *network;
-	const char *nick;
-	const char *pass;
+	char *network;
+	char *nick;
+	char *pass;
 };
 
 #endif /* __CTRLPROXY_NICKSERV_H__ */
