@@ -4,7 +4,7 @@
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
-	the Free Software Foundation; either version 2 of the License, or
+	the Free Software Foundation; either version 3 of the License, or
 	(at your option) any later version.
 
 	This program is distributed in the hope that it will be useful,
@@ -29,7 +29,7 @@
 #include <netdb.h>
 
 /* globals */
-char my_hostname[MAXHOSTNAMELEN+2];
+char my_hostname[NI_MAXHOST+2];
 
 const char *get_my_hostname() { return my_hostname; }
 const char *ctrlproxy_version() { return PACKAGE_VERSION; }
